##  POLL_RESULT_CREATED

```
{
  "type": "POLL_RESULT_CREATED",
  "pollRun": {
    "id": "0b38d423-7b15-4ecd-ae3e-175c9fb8134a",
    "poll": {
      "id": "3754281a-f8f2-43b5-8ec5-b78465f48be6",
      "title": "Update Life Cycle Dates",
      "status": "ACTIVE",
      "language": "en",
      "creatorId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
      "timeFrame": 0,
      "userQuery": {
        "roles": [
          {
            "roleDetails": [],
            "subscriptionType": "RESPONSIBLE"
          },
          {
            "roleDetails": [],
            "subscriptionType": "OBSERVER"
          }
        ]
      },
      "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
      "creationDate": "2024-02-16T13:31:19.391993Z",
      "factSheetType": "Application",
      "questionnaire": {
        "id": "5af9a9b9-6da1-465a-bc95-8344b9ec2fb2",
        "questions": [
          {
            "id": "9de72fa1-d999-bff3-eabb-ba3315bb479b",
            "type": "factsheetelement",
            "label": "Update life cycle",
            "deleted": false,
            "disabled": false,
            "powerfeature": true,
            "factSheetElement": {
              "type": "FACT_SHEET_FIELD",
              "factSheetFieldName": "lifecycle",
              "factSheetFieldType": "LIFECYCLE"
            }
          }
        ]
      },
      "factSheetQuery": {
        "ids": ["95fbeddd-abdf-4552-a82b-ce37c287735c"],
        "filter": {
          "facetFilter": [
            {
              "keys": ["Application"],
              "facetKey": "FactSheetTypes",
              "operator": "OR"
            }
          ]
        }
      },
      "repeatIntervall": 0,
      "introductionText": "...",
      "introductionSubject": "...",
      "additionalFactSheetText": "...",
      "allowedPermissionStatus": "ACTIVE_ONLY",
      "sendChangeNotifications": true,
      "additionalFactSheetSubject": "A Fact Sheet has been added to a Survey you are participating in",
      "additionalFactSheetCheckEnabled": true
    },
    "status": "PREPARING",
    "language": "en",
    "pollCopy": {
      "id": "3754281a-f8f2-43b5-8ec5-b78465f48be6",
      "title": "Update Life Cycle Dates",
      "status": "ACTIVE",
      "language": "en",
      "creatorId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
      "timeFrame": 0,
      "userQuery": {
        "roles": [
          {
            "roleDetails": [],
            "subscriptionType": "RESPONSIBLE"
          },
          {
            "roleDetails": [],
            "subscriptionType": "OBSERVER"
          }
        ]
      },
      "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
      "creationDate": "2024-02-16T13:31:19.391993Z",
      "factSheetType": "Application",
      "questionnaire": {
        "id": "5af9a9b9-6da1-465a-bc95-8344b9ec2fb2",
        "questions": [
          {
            "id": "9de72fa1-d999-bff3-eabb-ba3315bb479b",
            "type": "factsheetelement",
            "label": "Update life cycle",
            "deleted": false,
            "disabled": false,
            "powerfeature": true,
            "factSheetElement": {
              "type": "FACT_SHEET_FIELD",
              "factSheetFieldName": "lifecycle",
              "factSheetFieldType": "LIFECYCLE"
            }
          }
        ]
      },
      "factSheetQuery": {
        "ids": ["95fbeddd-abdf-4552-a82b-ce37c287735c"],
        "filter": {
          "facetFilter": [
            {
              "keys": ["Application"],
              "facetKey": "FactSheetTypes",
              "operator": "OR"
            }
          ]
        }
      },
      "repeatIntervall": 0,
      "introductionText": "...",
      "introductionSubject": "...",
      "additionalFactSheetText": "...",
      "allowedPermissionStatus": "ACTIVE_ONLY",
      "sendChangeNotifications": true,
      "additionalFactSheetSubject": "A Fact Sheet has been added to a Survey you are participating in",
      "additionalFactSheetCheckEnabled": true
    },
    "senderId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
    "startTime": "2024-02-16T13:40:56.246318Z",
    "resultView": "NEW",
    "pollRunType": "LIVE",
    "pollResultType": "PER_FACTSHEET",
    "factsheetsTotal": 1,
    "recipientsTotal": 2,
    "factsheetsProgress": 0,
    "factsheetsSelected": 1,
    "recipientsProgress": 0,
    "factsheetsCompleted": 0,
    "recipientsCompleted": 0,
    "sendChangeNotifications": true,
    "additionalFactSheetCheckEnabled": true
  },
  "createdAt": 1708090856819,
  "pollResult": {
    "id": "1eda2425-2d33-4c5e-a3e3-7f767770b778",
    "users": [
      {
        "id": "8393b7a8-8bfb-4989-a348-6cb31d56745f",
        "email": "john.smith@organization.com",
        "fullName": "John Smith",
        "lastName": "Smith",
        "firstName": "John"
      },
      {
        "id": "3et65c21-98f2-5376-acaa-fchf654b9c22",
        "email": "john.doe@organization.com",
        "fullName": "John Doe",
        "lastName": "Doe",
        "firstName": "John"
      }
    ],
    "sender": {
      "id": "3et65c21-98f2-5376-acaa-fchf654b9c22",
      "email": "john.doe@organization.com",
      "fullName": "John Doe",
      "lastName": "Doe",
      "firstName": "John"
    },
    "status": "NEW",
    "answers": [
      {
        "questionId": "9de72fa1-d999-bff3-eabb-ba3315bb479b"
      }
    ],
    "factSheet": {
      "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
      "name": "AC Management",
      "type": "Application",
      "displayName": "AC Management App"
    },
    "pollRunId": "0b38d423-7b15-4ecd-ae3e-175c9fb8134a"
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "pollResultEventType": "POLL_RESULT_CREATED"
}
```



